:maintainers:
  `andrewtarzia <https://github.com/andrewtarzia/>`_
:documentation: https://bbprepared.readthedocs.io/en/latest/


============
Introduction
============

:mod:`bbprepared` or ``bbprep`` is a toolkit aimed at simplifying the
preparation of your building blocks for
`stk <https://stk.readthedocs.io/en/stable/>`_ construction and analysis.


Installation
============

To get :mod:`.bbprepared`, you can install it with pip:

.. code-block:: bash

  pip install bbprepared

Developer Setup
---------------

To develop with :mod:`bbprepared`, you can clone the repo and use
`just <https://github.com/casey/just>`_ to setup the dev environment:

.. code-block:: bash

  just dev


Examples
========

* See `Recipes` for usage and the code tests include additional examples.
* See `gists <https://gist.github.com/andrewtarzia>`_ for usage.

How To Cite
===========

If you use ``bbprepared`` please cite

  https://github.com/andrewtarzia/bbprepared


Acknowledgements
================

Funded by the European Union - Next Generation EU, Mission 4 Component 1
CUP E13C22002930006 and the ERC under projects DYNAPOL.

This work is a mixture of codes developed throughout my postdoc in the
`Jelfs Group <http://www.jelfs-group.org/>`_, and the
`Pavan Group <https://www.gmpavanlab.com/>`_, and during my time as a developer
of `stk <https://stk.readthedocs.io/en/stable/>`_ and
`stko <https://github.com/JelfsMaterialsGroup/stko>`_ with Lukas Turcani.
